#include <Wire.h>

const int buttonPin = 4;   // The pin where the button is connected
int lastButtonState = LOW; // The previous reading from the input pin
int currentState = 0;      // State of the application

void setup() {
  pinMode(buttonPin, INPUT);
  Wire.begin(); // Start I2C as master
  Serial.begin(9600);
}

void loop() {
  int buttonState = digitalRead(buttonPin);

  // Check if the button has been pressed 
  if (buttonState == HIGH && lastButtonState == LOW) {
    delay(50); // Debouncing
    currentState++;
    if (currentState > 2) currentState = 0;

    switch (currentState) {
      case 0:
        sendCommand(0x08, 0); // Stop motor on slave 1
        sendCommand(0x09, 0); // Stop motor on slave 2
        break;
      case 1:
        sendCommand(0x08, 1); // Start motor on slave 1
        sendCommand(0x09, 0); // Ensure motor on slave 2 is stopped
        break;
      case 2:
        sendCommand(0x08, 0); // Stop motor on slave 1
        sendCommand(0x09, 1); // Start motor on slave 2
        break;
    }
  }

  lastButtonState = buttonState; // Save the current state as the last state, for next time through the loop
  delay(10);
}

void sendCommand(byte address, byte command) {
  Wire.beginTransmission(address);
  Wire.write(command);
  Wire.endTransmission();
}
